@@ -29,9 +29,7 @@ def cleanup_names(df):
 try:
     import pyspark.sql.functions as f
     f.col('f')
-    MOCK=False
 except AttributeError:
-    MOCK=True
     f = mock_functions()
 
 #
@@ -143,10 +141,7 @@ class Package:
     def cleanup(self, msg, meta = {"db2quilt":"v0.1"}):
         self.write_summary()
         QPKG.set_dir('/',path=self.path, meta=meta)
-        if MOCK:
-            QPKG.push(self.name, self.proj.repo, message=msg) #, force=True
-        else:
-            QPKG.push(self.name, self.proj.repo, message=msg,force=True) #,
+        QPKG.push(self.name, self.proj.repo, message=msg,force=True) #,
         #shutil.rmtree(self.path)
         self.html = f'Published <a href="{self.url}">{self.name}</a> for <b>{msg}</b>'
         return self
@@ -269,10 +264,10 @@ def exract_pkg(cvm):
     #pkg.setup()
     return pkg
 
-def cvm2pkg(cvm):
+def cvm2pkg(cvm, run=True):
+    if run: cvm.run()
     pkg = exract_pkg(cvm)
     cvm.pkg = pkg
-    cvm.run()
     doc = cvm.key_actions('doc')
     doc["cvm.actions"] = cvm.actions
     pkg.save_dict(cvm.actions, pkg.id)
